@@ -5,7 +5,7 @@
  */
 
 #include <libxml++/nodes/entitydeclaration.h>
-#include <libxml/tree.h>
+#include <libxml/entities.h>
 
 namespace xmlpp
 {
